﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;


namespace Merthsoft.CALCnet {
	/// <summary>
	/// A directed packet.
	/// </summary>
	public class DirectPacket : CALCnetPacket {
		protected static byte[] Header = new byte[] { 255, 137 };
		protected static byte Footer = 42;

		/// <summary>
		/// Gets the calc ID that is sending this packet.
		/// </summary>
		public byte[] CalcID {
			get;
			protected set;
		}

		/// <summary>
		/// Gets the calc ID that this packet is going to
		/// </summary>
		public byte[] ToID {
			get;
			protected set;
		}

		/// <summary>
		/// Gets the data in the packet.
		/// </summary>
		public byte[] Data {
			get;
			protected set;
		}

		/// <summary>
		/// Initializes a new directed packet from calcID to toID with data data
		/// </summary>
		/// <param name="calcID">The calculator that is sending the packet</param>
		/// <param name="toID">The calculator that is receiving the packet</param>
		/// <param name="data">The data within the packet</param>
		public DirectPacket(ICollection<byte> calcID, ICollection<byte> toID, ICollection<byte> data) {
			if (calcID.Count != 5) {
				throw new ArgumentException("calcID must be 5 bytes long");
			}
			if (toID.Count != 5) {
				throw new ArgumentException("toID must be 5 bytes long");
			}
			CalcID = calcID.ToArray();
			Data = data.ToArray();
			ToID = toID.ToArray();
			Type = PacketType.Directed;
			List<byte> payload = new List<byte>();
			payload.AddRange(Header);
			payload.AddRange(toID);
			payload.AddRange(calcID);
			payload.AddRange(((short)data.Count).GetBytes());
			payload.AddRange(data);
			payload.Add(Footer);

			Payload = payload;
		}
	}
}
