﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Merthsoft.CALCnet {
	/// <summary>
	/// The packet sent when a calculator joins
	/// </summary>
	class JoinPacket : CALCnetPacket {
		private string _hubName = "";
		/// <summary>
		/// Gets the meta-hub that this packet is associated with
		/// </summary>
		public string HubName {
			get { return _hubName; }
			protected set {
				_hubName = value;
			}
		}
		
		private string _localClient = "";
		/// <summary>
		/// Gets the local client that this packet is associated with
		/// </summary>
		public string LocalClient {
			get { return _localClient; }
			protected set {
				_localClient = value;
			}
		}
		
		/// <summary>
		/// Creates a new join packet with the given hubname and localclient name
		/// </summary>
		/// <param name="hubName">The name of the meta-hub</param>
		/// <param name="localClient">The local client name</param>
		public JoinPacket(string hubName, string localClient) {
			Type = PacketType.Join;
			HubName = hubName;
			LocalClient = localClient;

			List<byte> p = new List<byte>();
			p.Add((byte)HubName.Length);
			p.AddRange(HubName.ToByteArray());
			p.Add((byte)LocalClient.Length);
			p.AddRange(LocalClient.ToByteArray());

			Payload = p;
		}
	}
}
